==> didwegivecredit-0.0.1.tar.gz: didwegivecredit-0.0.1/setup.py <==
#!/usr/bin/env python

"""The setup script."""

from setuptools import setup, find_packages

with open('README.rst') as readme_file:
    readme = readme_file.read()

with open('HISTORY.rst') as history_file:
    history = history_file.read()

requirements = ['emoji',
                'fuzzywuzzy']

setup_requirements = ['pytest-runner', ]

test_requirements = ['pytest>=3', ]

setup(
    author="Adina Wagner",
    author_email='adina.wagner@t-online.de',
    python_requires='>=3.5',
    classifiers=[
        'Development Status :: 2 - Pre-Alpha',
        'Intended Audience :: Developers',
        'License :: OSI Approved :: MIT License',
        'Natural Language :: English',
        'Programming Language :: Python :: 3',
        'Programming Language :: Python :: 3.5',
        'Programming Language :: Python :: 3.6',
        'Programming Language :: Python :: 3.7',
        'Programming Language :: Python :: 3.8',
    ],
    description="A small linter that checks whether committers to a repository are acknowledged with all-contributors",
    entry_points={
        'console_scripts': [
            'didwegivecredit=didwegivecredit.cli:main',
        ],
    },
    install_requires=requirements,
    license="MIT license",
    long_description=readme + '\n\n' + history,
    include_package_data=True,
    keywords='didwegivecredit',
    name='didwegivecredit',
    packages=find_packages(include=['didwegivecredit', 'didwegivecredit.*']),
    setup_requires=setup_requirements,
    test_suite='tests',
    tests_require=test_requirements,
    url='https://github.com/adswa/didwegivecredit',
    version='0.0.1',
    zip_safe=False,
)

==> didwegivecredit-0.0.2.tar.gz: didwegivecredit-0.0.2/setup.py <==
#!/usr/bin/env python

"""The setup script."""

from setuptools import setup, find_packages

with open('README.rst') as readme_file:
    readme = readme_file.read()

with open('HISTORY.rst') as history_file:
    history = history_file.read()

requirements = ['rich',
                'fuzzywuzzy']

setup_requirements = ['pytest-runner', ]

test_requirements = ['pytest>=3', ]

setup(
    author="Adina Wagner",
    author_email='adina.wagner@t-online.de',
    python_requires='>=3.5',
    classifiers=[
        'Development Status :: 2 - Pre-Alpha',
        'Intended Audience :: Developers',
        'License :: OSI Approved :: MIT License',
        'Natural Language :: English',
        'Programming Language :: Python :: 3',
        'Programming Language :: Python :: 3.5',
        'Programming Language :: Python :: 3.6',
        'Programming Language :: Python :: 3.7',
        'Programming Language :: Python :: 3.8',
    ],
    description="A small linter that checks whether committers to a repository are acknowledged with all-contributors",
    entry_points={
        'console_scripts': [
            'didwegivecredit=didwegivecredit.cli:main',
        ],
    },
    install_requires=requirements,
    license="MIT license",
    long_description=readme + '\n\n' + history,
    include_package_data=True,
    keywords='didwegivecredit',
    name='didwegivecredit',
    packages=find_packages(include=['didwegivecredit', 'didwegivecredit.*']),
    setup_requires=setup_requirements,
    test_suite='tests',
    tests_require=test_requirements,
    url='https://github.com/adswa/didwegivecredit',
    version='0.0.2',
    zip_safe=False,
)
